# Opensource PBL2 : Opensource console software

> 리눅스 운영 도구 및 컨설팅을 공급하는 Redhat 사에 속한 우리 팀은, 클라이언트의 요청을 받아 클라이언트 사내에서 사용할 수 있는 콘솔 기반의 어플리케이션을 개발하는 작업을 진행하게 되었다. 이 어플리케이션은 사용자의 TODO 리스트를 리눅스 콘솔 기반으로 사용할 수 있도록 돕는 콘솔용의 어플리케이션이다.

<br />

| Member | Role | Github |
|------------------------|---------|--------|
| 양재우 | Project Manager | [onnoo](https://github.com/onnoo) |
| 김재훈 | Programmer | [anmyeondo](https://github.com/anmyeondo) |
| 안진성 | Programmer | [RDCPP](https://github.com/RDCPP) |
| 김건기 | Maintenance | [KEON-KIM](https://github.com/KEON-KIM) |
| 김성찬 | Maintenance | [ksccmp](https://github.com/ksccmp) |

<br />